/* Schedwi
   Copyright (C) 2007 Herve Quatremain
     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
     
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Library General Public License for more details.
     
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/* sql_hierarchy.h -- Get the job hierarchy and parameters */

#ifndef _SQL_HIERARCHY_H
#define _SQL_HIERARCHY_H

#include <schedwi.h>
#include <lwc_linkedlist.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern unsigned int get_job_path OF((	const char *job_id, char **path,
					char **err_msg));
extern lwc_LL *get_hierarchy_list OF((	int workload_date,
					const char *job_id, char **err_msg));
extern lwc_LL *duplicate_hierarchy_list OF((lwc_LL *lst, char **err_msg));
extern int hierarchy_list_to_str OF((lwc_LL *lst, char **result));
extern unsigned int get_job_parameters OF((
			int workload_date,
			lwc_LL *lst,
			const char *tablename, const char *colnames,
			char ***values, unsigned long int **values_len,
			char **err_msg));
extern unsigned int get_job_parameter OF((
			int workload_date,
			lwc_LL *lst,
			const char *tablename, const char *colname,
			char **value, unsigned long int *value_len,
			char **err_msg));
extern unsigned int get_job_parameters_multi_row OF((
			int workload_date,
			lwc_LL *lst,
			const char *tablename, const char *colnames,
			const char *sort_colname,
			lwc_LL **rows, lwc_LL **rows_len,
			char **err_msg));
extern unsigned int get_job_parameters_multi OF((
			int workload_date,
			lwc_LL *lst,
			const char *tablename, const char *colnames,
			const char *sort_colname,
			int (*callback)(void *, char **,
					unsigned long int *),
			void *user_data,
			char **err_msg));
extern unsigned int get_job_parameters_by_id OF((
			int workload_date,
			lwc_LL *lst,
			const char *tablename, const char *colnames,
			const char *not_defined,
			char ***values, unsigned long int **values_len,
			char **err_msg));

extern unsigned int get_job_id OF((
		const char *job_name,
		char **j_id, char **j_parent_id, char **j_type,
		void (*error_func)(void *, const char *, unsigned int),
		void *user_data_error_func));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* sql_hierarchy.h */

/*-----------------============== End Of File ==============-----------------*/
